/*******************************************************************************
* File Name: Ctrl_StartCount_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "Ctrl_StartCount.h"

/* Check for removal by optimization */
#if !defined(Ctrl_StartCount_Sync_ctrl_reg__REMOVED)

static Ctrl_StartCount_BACKUP_STRUCT  Ctrl_StartCount_backup = {0u};

    
/*******************************************************************************
* Function Name: Ctrl_StartCount_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Ctrl_StartCount_SaveConfig(void) 
{
    Ctrl_StartCount_backup.controlState = Ctrl_StartCount_Control;
}


/*******************************************************************************
* Function Name: Ctrl_StartCount_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void Ctrl_StartCount_RestoreConfig(void) 
{
     Ctrl_StartCount_Control = Ctrl_StartCount_backup.controlState;
}


/*******************************************************************************
* Function Name: Ctrl_StartCount_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Ctrl_StartCount_Sleep(void) 
{
    Ctrl_StartCount_SaveConfig();
}


/*******************************************************************************
* Function Name: Ctrl_StartCount_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Ctrl_StartCount_Wakeup(void)  
{
    Ctrl_StartCount_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
