/*******************************************************************************
* File Name: ResetClk.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_ResetClk_H)
#define CY_CLOCK_ResetClk_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_20 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void ResetClk_Start(void) ;
void ResetClk_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void ResetClk_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void ResetClk_StandbyPower(uint8 state) ;
void ResetClk_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 ResetClk_GetDividerRegister(void) ;
void ResetClk_SetModeRegister(uint8 modeBitMask) ;
void ResetClk_ClearModeRegister(uint8 modeBitMask) ;
uint8 ResetClk_GetModeRegister(void) ;
void ResetClk_SetSourceRegister(uint8 clkSource) ;
uint8 ResetClk_GetSourceRegister(void) ;
#if defined(ResetClk__CFG3)
void ResetClk_SetPhaseRegister(uint8 clkPhase) ;
uint8 ResetClk_GetPhaseRegister(void) ;
#endif /* defined(ResetClk__CFG3) */

#define ResetClk_Enable()                       ResetClk_Start()
#define ResetClk_Disable()                      ResetClk_Stop()
#define ResetClk_SetDivider(clkDivider)         ResetClk_SetDividerRegister(clkDivider, 1u)
#define ResetClk_SetDividerValue(clkDivider)    ResetClk_SetDividerRegister((clkDivider) - 1u, 1u)
#define ResetClk_SetMode(clkMode)               ResetClk_SetModeRegister(clkMode)
#define ResetClk_SetSource(clkSource)           ResetClk_SetSourceRegister(clkSource)
#if defined(ResetClk__CFG3)
#define ResetClk_SetPhase(clkPhase)             ResetClk_SetPhaseRegister(clkPhase)
#define ResetClk_SetPhaseValue(clkPhase)        ResetClk_SetPhaseRegister((clkPhase) + 1u)
#endif /* defined(ResetClk__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define ResetClk_CLKEN              (* (reg8 *) ResetClk__PM_ACT_CFG)
#define ResetClk_CLKEN_PTR          ((reg8 *) ResetClk__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define ResetClk_CLKSTBY            (* (reg8 *) ResetClk__PM_STBY_CFG)
#define ResetClk_CLKSTBY_PTR        ((reg8 *) ResetClk__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define ResetClk_DIV_LSB            (* (reg8 *) ResetClk__CFG0)
#define ResetClk_DIV_LSB_PTR        ((reg8 *) ResetClk__CFG0)
#define ResetClk_DIV_PTR            ((reg16 *) ResetClk__CFG0)

/* Clock MSB divider configuration register. */
#define ResetClk_DIV_MSB            (* (reg8 *) ResetClk__CFG1)
#define ResetClk_DIV_MSB_PTR        ((reg8 *) ResetClk__CFG1)

/* Mode and source configuration register */
#define ResetClk_MOD_SRC            (* (reg8 *) ResetClk__CFG2)
#define ResetClk_MOD_SRC_PTR        ((reg8 *) ResetClk__CFG2)

#if defined(ResetClk__CFG3)
/* Analog clock phase configuration register */
#define ResetClk_PHASE              (* (reg8 *) ResetClk__CFG3)
#define ResetClk_PHASE_PTR          ((reg8 *) ResetClk__CFG3)
#endif /* defined(ResetClk__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define ResetClk_CLKEN_MASK         ResetClk__PM_ACT_MSK
#define ResetClk_CLKSTBY_MASK       ResetClk__PM_STBY_MSK

/* CFG2 field masks */
#define ResetClk_SRC_SEL_MSK        ResetClk__CFG2_SRC_SEL_MASK
#define ResetClk_MODE_MASK          (~(ResetClk_SRC_SEL_MSK))

#if defined(ResetClk__CFG3)
/* CFG3 phase mask */
#define ResetClk_PHASE_MASK         ResetClk__CFG3_PHASE_DLY_MASK
#endif /* defined(ResetClk__CFG3) */

#endif /* CY_CLOCK_ResetClk_H */


/* [] END OF FILE */
