#include <project.h>

#define PWM_VAL_0   14
#define PWM_VAL_1   42

#define MAX_BIT_INDEX   8

#define G_INDEX 0
#define R_INDEX 1
#define B_INDEX 2

static volatile uint8_t Bytes_Out[3] = {0x00, 0xFF, 0xAA};

void PWM_ISR_Interrupt_InterruptCallback(void){
    static uint8_t byte_index = 0;
    static uint8_t bit_index = MAX_BIT_INDEX;
    PWM_ReadStatusRegister();
    
    if (Ctrl_StartCount_Read() > 0){
        
        if (((Bytes_Out[byte_index] >> --bit_index) & 0x01) > 0){
            PWM_WriteCompare(PWM_VAL_1);
        } else {
            PWM_WriteCompare(PWM_VAL_0);
        }
        
        if (bit_index == 0){
            byte_index++;
            bit_index = MAX_BIT_INDEX;
        }
        
        if (byte_index >= 3){
            /*Transmission Done*/
            byte_index = 0;   
            Ctrl_StartCount_Write(0);
        }
    
    } else {
        /*Not Transmitting - Set PWM back to 0*/
        PWM_WriteCompare(PWM_INIT_COMPARE_VALUE1);
    }
    
    PWM_ISR_ClearPending();
}

int main()
{
    CyGlobalIntEnable;
    
    PWM_Start();
    PWM_ISR_Start();
    
    for(;;)
    {
        /*Only write to StartCount if we are not currently transmitting*/
        if (SW2_Read() == 0 && Ctrl_StartCount_Read() == 0){
            Ctrl_StartCount_Write(1);
        }
        
        
    }
}

/* [] END OF FILE */
